@@ -2,5 +2,6 @@
 """
 CMSMonitoring: set of utils for CMS monitoring
 """
-__version__ = '0.5.2'
-__all__ = []
+# Check GH actions
+__version__ = "0.6.2"
+__all__ = [__version__]
